# -*- coding: utf-8 -*-
from setuphelpers import *
import requests
import platform
import bs4 as BeautifulSoup

# Installation procedure: https://docs.python.org/2/using/windows.html

# Declaring specific app values (TO CHANGE)
bin_name_string = "python-%s.amd64.msi"


def update_package():
    print("Download/Update package content from upstream binary sources")

    # Getting proxy informations from WAPT settings
    proxy = {}
    if platform.system() == "Windows" and isfile(makepath(user_local_appdata(), "waptconsole", "waptconsole.ini")):
        proxywapt = inifile_readstring(makepath(user_local_appdata(), "waptconsole", "waptconsole.ini"), "global", "http_proxy")
        if proxywapt:
            proxy = {"http": proxywapt, "https": proxywapt}

    # Specific app values
    app_name = control.name
    url = control.sources

    # Getting latest version from official website
    page = requests.get(url, headers={"User-Agent": "Mozilla/5.0 (Windows NT 6.1; Win64; x64)"}).text
    bs = BeautifulSoup.BeautifulSoup(page, features="html.parser")
    bs_list = bs.findAll("a")
    for vers in bs_list:
        if vers.text.startswith("Latest Python 2 Release"):
            version = vers.text.split(" ")[-1]
            break

    latest_bin = bin_name_string % version
    url_dl = "https://www.python.org/ftp/python/%s/%s" % (version, latest_bin)

    print("Latest " + app_name + " version is: " + version)
    print("Download url is: " + url_dl)

    # Downloading latest binaries
    if not isfile(latest_bin):
        print("Downloading: " + latest_bin)
        wget(url_dl, latest_bin, proxies=proxy)

        # Checking version from file
        version_from_file = get_msi_properties(latest_bin)["ProductName"].split(" ")[1]
        if version != version_from_file and version_from_file != "":
            version = version_from_file
            old_latest_bin = latest_bin
            latest_bin = bin_name_string % version
            if isfile(latest_bin):
                remove_file(latest_bin)
            os.rename(old_latest_bin, latest_bin)

        # Changing version of the package
        pe = PackageEntry().load_control_from_wapt(".")
        pe.version = "%s-%s" % (version, int(pe.version.split("-", 1)[1]) + 1)
        pe.save_control_to_wapt(".")
        print("Changing version to " + pe.version + " in WAPT\\control")
        print("Update package done. You can now build-upload your package")
    else:
        print("This package is already up-to-date")

    # # Getting latest Python PIP
    # page = requests.get('https://pypi.org/project/pip/#files',headers={'User-Agent':'Mozilla/5.0 (Windows NT 6.1; Win64; x64)'}).text
    # bs = BeautifulSoup.BeautifulSoup(page,features="html.parser")
    # url_dl_pip = bs.find('span',{'class':'table__mobile-label'}).find_next()['href']
    # latest_bin_pip = url_dl_pip.split('/')[-1]
    # if not isfile(latest_bin_pip):
    #     print('Downloading: ' + latest_bin_pip)
    #     wget(url_dl_pip,makepath(whl_dir,latest_bin_pip),proxies=proxy)

    # Deleting outdated binaries
    for bin_in_dir in glob.glob("*.exe") or glob.glob("*.msi") or glob.glob("*.zip"):
        if bin_in_dir != latest_bin:
            print("Outdated binary: " + bin_in_dir + " Deleted")
            remove_file(bin_in_dir)
